@@ -15,7 +15,7 @@ use crate::{
         enums::GovernanceAccountType,
         realm::{
             assert_valid_realm_config_args, get_governing_token_holding_address_seeds,
-            get_realm_address_seeds, Realm, RealmConfig, RealmConfigArgs,
+            get_realm_address_seeds, RealmConfig, RealmConfigArgs, RealmV2,
         },
         realm_config::{get_realm_config_address_seeds, RealmConfigAccount},
     },
@@ -83,15 +83,32 @@ pub fn process_create_realm(
         None
     };
 
-    if config_args.use_community_voter_weight_addin {
-        let realm_config_info = next_account_info(account_info_iter)?; // 10
-        let community_voter_weight_addin_info = next_account_info(account_info_iter)?; //11
+    // Setup config for addins
+
+    let community_voter_weight_addin = if config_args.use_community_voter_weight_addin {
+        let community_voter_weight_addin_info = next_account_info(account_info_iter)?; // 10
+        Some(*community_voter_weight_addin_info.key)
+    } else {
+        None
+    };
+
+    let max_community_voter_weight_addin = if config_args.use_max_community_voter_weight_addin {
+        let max_community_voter_weight_addin_info = next_account_info(account_info_iter)?; // 11
+        Some(*max_community_voter_weight_addin_info.key)
+    } else {
+        None
+    };
+
+    if config_args.use_community_voter_weight_addin
+        || config_args.use_max_community_voter_weight_addin
+    {
+        let realm_config_info = next_account_info(account_info_iter)?; // 12
 
         let realm_config_data = RealmConfigAccount {
             account_type: GovernanceAccountType::RealmConfig,
             realm: *realm_info.key,
-            community_voter_weight_addin: Some(*community_voter_weight_addin_info.key),
-            community_max_vote_weight_addin: None,
+            community_voter_weight_addin,
+            max_community_voter_weight_addin,
             council_voter_weight_addin: None,
             council_max_vote_weight_addin: None,
             reserved: [0; 128],
@@ -108,25 +125,28 @@ pub fn process_create_realm(
         )?;
     }
 
-    let realm_data = Realm {
-        account_type: GovernanceAccountType::Realm,
+    let realm_data = RealmV2 {
+        account_type: GovernanceAccountType::RealmV2,
         community_mint: *governance_token_mint_info.key,
 
         name: name.clone(),
-        reserved: [0; 8],
+        reserved: [0; 6],
         authority: Some(*realm_authority_info.key),
         config: RealmConfig {
             council_mint: council_token_mint_address,
-            reserved: [0; 7],
+            reserved: [0; 6],
             community_mint_max_vote_weight_source: config_args
                 .community_mint_max_vote_weight_source,
-            min_community_tokens_to_create_governance: config_args
-                .min_community_tokens_to_create_governance,
+            min_community_weight_to_create_governance: config_args
+                .min_community_weight_to_create_governance,
             use_community_voter_weight_addin: config_args.use_community_voter_weight_addin,
+            use_max_community_voter_weight_addin: config_args.use_max_community_voter_weight_addin,
         },
+        voting_proposal_count: 0,
+        reserved_v2: [0; 128],
     };
 
-    create_and_serialize_account_signed::<Realm>(
+    create_and_serialize_account_signed::<RealmV2>(
         payer_info,
         realm_info,
         &realm_data,
