@@ -137,12 +137,33 @@ pub struct GovernanceV1 {
     pub voting_proposal_count: u16,
 }
 
-/// Checks if the given account type is one of the Governance account types
+/// Checks if the given account type is one of the Governance V1 account types
 pub fn is_governance_v1_account_type(account_type: &GovernanceAccountType) -> bool {
-    *account_type == GovernanceAccountType::GovernanceV1
-        || *account_type == GovernanceAccountType::ProgramGovernanceV1
-        || *account_type == GovernanceAccountType::MintGovernanceV1
-        || *account_type == GovernanceAccountType::TokenGovernanceV1
+    match account_type {
+        GovernanceAccountType::GovernanceV1
+        | GovernanceAccountType::ProgramGovernanceV1
+        | GovernanceAccountType::MintGovernanceV1
+        | GovernanceAccountType::TokenGovernanceV1 => true,
+        GovernanceAccountType::Uninitialized
+        | GovernanceAccountType::RealmV1
+        | GovernanceAccountType::RealmV2
+        | GovernanceAccountType::RealmConfig
+        | GovernanceAccountType::TokenOwnerRecordV1
+        | GovernanceAccountType::TokenOwnerRecordV2
+        | GovernanceAccountType::GovernanceV2
+        | GovernanceAccountType::ProgramGovernanceV2
+        | GovernanceAccountType::MintGovernanceV2
+        | GovernanceAccountType::TokenGovernanceV2
+        | GovernanceAccountType::ProposalV1
+        | GovernanceAccountType::ProposalV2
+        | GovernanceAccountType::SignatoryRecordV1
+        | GovernanceAccountType::SignatoryRecordV2
+        | GovernanceAccountType::ProposalInstructionV1
+        | GovernanceAccountType::ProposalTransactionV2
+        | GovernanceAccountType::VoteRecordV1
+        | GovernanceAccountType::VoteRecordV2
+        | GovernanceAccountType::ProgramMetadata => false,
+    }
 }
 
 impl IsInitialized for GovernanceV1 {
